==> openshift-model-console-6.5.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ApplicationMenuSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ApplicationMenuSpecFluentImpl<A extends ApplicationMenuSpecFluent<A>> extends BaseFluent<A> implements ApplicationMenuSpecFluent<A>{
  public ApplicationMenuSpecFluentImpl() {
  }
  public ApplicationMenuSpecFluentImpl(ApplicationMenuSpec instance) {
    this.withImageURL(instance.getImageURL()); 
    this.withSection(instance.getSection()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String imageURL;
  private String section;
  private Map<String,Object> additionalProperties;
  public String getImageURL() {
    return this.imageURL;
  }
  public A withImageURL(String imageURL) {
    this.imageURL=imageURL; return (A) this;
  }
  public Boolean hasImageURL() {
    return this.imageURL != null;
  }
  public String getSection() {
    return this.section;
  }
  public A withSection(String section) {
    this.section=section; return (A) this;
  }
  public Boolean hasSection() {
    return this.section != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ApplicationMenuSpecFluentImpl that = (ApplicationMenuSpecFluentImpl) o;
    if (imageURL != null ? !imageURL.equals(that.imageURL) :that.imageURL != null) return false;
    if (section != null ? !section.equals(that.section) :that.section != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imageURL,  section,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (imageURL != null) { sb.append("imageURL:"); sb.append(imageURL + ","); }
    if (section != null) { sb.append("section:"); sb.append(section + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-console-6.7.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ApplicationMenuSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ApplicationMenuSpecFluentImpl<A extends ApplicationMenuSpecFluent<A>> extends BaseFluent<A> implements ApplicationMenuSpecFluent<A>{
  public ApplicationMenuSpecFluentImpl() {
  }
  public ApplicationMenuSpecFluentImpl(ApplicationMenuSpec instance) {
    if (instance != null) {
      this.withImageURL(instance.getImageURL());
      this.withSection(instance.getSection());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String imageURL;
  private String section;
  private Map<String,Object> additionalProperties;
  public String getImageURL() {
    return this.imageURL;
  }
  public A withImageURL(String imageURL) {
    this.imageURL=imageURL; return (A) this;
  }
  public Boolean hasImageURL() {
    return this.imageURL != null;
  }
  public String getSection() {
    return this.section;
  }
  public A withSection(String section) {
    this.section=section; return (A) this;
  }
  public Boolean hasSection() {
    return this.section != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ApplicationMenuSpecFluentImpl that = (ApplicationMenuSpecFluentImpl) o;
    if (!java.util.Objects.equals(imageURL, that.imageURL)) return false;

    if (!java.util.Objects.equals(section, that.section)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imageURL,  section,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (imageURL != null) { sb.append("imageURL:"); sb.append(imageURL + ","); }
    if (section != null) { sb.append("section:"); sb.append(section + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
